==> Moony-0.9.0.tgz: Moony-0.9.0/Moony/View.php <==
<?php
/**
 * Moony - a simple web application framework
 *
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @copyright 2005-2006 YAMAOKA Hiroyuki
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

/**
 * テンプレートを操作するためのクラスです。
 * Smartyのサブクラスとして実装されています。
 * 
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @copyright 2005-2006 YAMAOKA Hiroyuki
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 * @access public
 */
class Moony_View extends Smarty
{
    /**
     * コンストラクタです。
     *
     * @access public
     */
    function Moony_View()
    {
        $this->Smarty();

        $this->template_dir = MOONY_SMARTY_TEMPLATE_DIR;
        $this->config_dir = MOONY_SMARTY_TEMPLATE_DIR;
        $this->compile_dir = MOONY_SMARTY_WORK_DIR;
        $this->cache_dir = MOONY_SMARTY_WORK_DIR;

        // エンコーディングが異なっている場合にフィルタ
        if (MOONY_TEMPLATE_ENCODING != MOONY_INTERNAL_ENCODING) {
            $this->register_prefilter(array('Moony_View', 'prefilter'));
        }
        if (MOONY_OUTPUT_ENCODING != MOONY_INTERNAL_ENCODING) {
            // mb_output_handlerで変換する場合は何もしない
            $handlers = ob_list_handlers();
            if (!in_array('mb_output_handler', $handlers)) {
                $this->register_outputfilter(array('Moony_View', 'outputFilter'));
            }
        }
    }

    /**
     * 指定されたテンプレートを利用して、
     * 画面描画処理を行います。
     * 
     * @access public
     * @param object $response Moony_Responseのインスタンス
     */
    function render(&$response)
    {
        // テンプレート存在チェック
        $template = $response->getTemplate();
        if (!$this->template_exists($template)) {
            Moony_Logger::warn('Template file not found: ' . $template, __FILE__, __LINE__);
            Moony_Error::notFound();
            exit(1);
        }

        // 値の設定
        $attributes = $response->getAll();
        $this->assign($attributes);

        // エンコーディングヘッダ出力
        if (MOONY_SENDING_HEADER_ABOUT_ENCODING) {
            $encoding = MOONY_OUTPUT_ENCODING;
            if (MOONY_OUTPUT_ENCODING == 'SJIS') {
                $encoding = 'Shift_JIS';
            }
            if (MOONY_USE_XHTML_HEADER) {
                header("Content-Type: application/xhtml+xml; charset=${encoding}");
            } else {
                header("Content-Type: text/html; charset=${encoding}");
            }
        }

        $this->display($template);
    }

    /**
     * Smartyで使用されるプリフィルタです。
     *
     * @access public
     * @static
     * @param string $src テンプレートファイルの内容
     * @param object $smarty Smartyのインスタンス
     */
    function prefilter($src, &$smarty)
    {
        return mb_convert_encoding($src, MOONY_INTERNAL_ENCODING, MOONY_TEMPLATE_ENCODING);
    }

    /**
     * Smartyで使用される出力フィルタです。
     *
     * @access public
     * @static
     * @param string $src テンプレートファイルの内容
     * @param object $smarty Smartyのインスタンス
     */
    function outputFilter($src, &$smarty)
    {
        return mb_convert_encoding($src, MOONY_OUTPUT_ENCODING, MOONY_INTERNAL_ENCODING);
    }
}
?>

==> Moony-0.10.0.tgz: Moony-0.10.0/Moony/View.php <==
<?php
/**
 * Moony - a simple web application framework
 *
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @copyright 2005-2006 YAMAOKA Hiroyuki
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

/**
 * テンプレートを操作するためのクラスです。
 * Smartyを利用して実装されています。
 * 
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @copyright 2005-2006 YAMAOKA Hiroyuki
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 * @access public
 */
class Moony_View
{
    /** @var object Smartyのインスタンス */
    var $smarty;

    /**
     * コンストラクタです。
     * Smartyの動作に必要な設定を行います。
     *
     * @access public
     */
    function Moony_View()
    {
        $this->smarty = new Smarty();
        $this->smarty->template_dir = MOONY_SMARTY_TEMPLATE_DIR;
        $this->smarty->config_dir = MOONY_SMARTY_TEMPLATE_DIR;
        $this->smarty->compile_dir = MOONY_SMARTY_WORK_DIR;
        $this->smarty->cache_dir = MOONY_SMARTY_WORK_DIR;
        $this->smarty->left_delimiter = MOONY_LEFT_DELIMITER;
        $this->smarty->right_delimiter = MOONY_RIGHT_DELIMITER;

        // エンコーディングが異なっている場合にフィルタ
        if (MOONY_TEMPLATE_ENCODING != MOONY_INTERNAL_ENCODING) {
            $this->smarty->register_prefilter(array('Moony_View', 'prefilter'));
        }
        if (MOONY_OUTPUT_ENCODING != MOONY_INTERNAL_ENCODING) {
            // mb_output_handlerで変換する場合は何もしない
            $handlers = ob_list_handlers();
            if (!in_array('mb_output_handler', $handlers)) {
              $this->smarty->register_outputfilter(array('Moony_View', 'outputfilter'));
            }
        }
    }

    /**
     * 画面描画処理を行います。
     * 
     * @access public
     * @param object $response Moony_Responseのインスタンス
     */
    function render(&$response)
    {
        // テンプレート存在チェック
        $template = $response->getTemplate();
        if (!$this->smarty->template_exists($template)) {
            Moony_Logger::warn('Template file not found: ' . $template, __FILE__, __LINE__);
            Moony_Error::notFound();
        }

        // 値の設定
        $attributes = $response->getAll();
        $this->smarty->assign($attributes);

        // エンコーディングヘッダ出力
        if (MOONY_SENDING_HEADER_ABOUT_ENCODING) {
            $encoding = MOONY_OUTPUT_ENCODING;
            if (MOONY_OUTPUT_ENCODING == 'SJIS') {
                $encoding = 'Shift_JIS';
            }
            if (MOONY_USE_XHTML_HEADER) {
                header("Content-Type: application/xhtml+xml; charset=${encoding}");
            } else {
                header("Content-Type: text/html; charset=${encoding}");
            }
        }

        $this->smarty->display($template);
    }

    /**
     * Smartyで使用されるプリフィルタです。
     *
     * @access public
     * @static
     * @param string $src テンプレートファイルの内容
     * @param object $smarty Smartyのインスタンス
     */
    function prefilter($src, &$smarty)
    {
        return mb_convert_encoding($src, MOONY_INTERNAL_ENCODING, MOONY_TEMPLATE_ENCODING);
    }

    /**
     * Smartyで使用される出力フィルタです。
     *
     * @access public
     * @static
     * @param string $src テンプレートファイルの内容
     * @param object $smarty Smartyのインスタンス
     */
    function outputfilter($src, &$smarty)
    {
        return mb_convert_encoding($src, MOONY_OUTPUT_ENCODING, MOONY_INTERNAL_ENCODING);
    }
}
?>
